@@ -2,7 +2,7 @@ import pandas as pd
 import numpy as np
 import datetime, random
 
-__version__ = '0.1.8' 
+__version__ = '0.2.0'  
 
 class AKIFlagger:
     ''' Main flagger to detect patients with acute kidney injury (AKI).
@@ -174,15 +174,20 @@ class AKIFlagger:
         if self.rolling_window:
             rw = self.addRollingWindowAKI(df)
             
-            # We only want the rolling-window to start from 6 hours prior to admission
-            mask = df.index.get_level_values(level = self.time) >= df[self.admission] - pd.Timedelta('6hours')
-            rw[~mask] = 0
+            # Commented out code is if we are only interested in starting the rolling window from 6 hours prior to admission (old rule)
+            #mask = df.index.get_level_values(level = self.time) >= df[self.admission] - pd.Timedelta('6hours')
+            #try:
+            #    rw[~mask] = 0
+            #except TypeError: # If add_min_creat is True but this is just a convenient way to encode that
+            #    rw[0][~mask] = 0
 
         if self.back_calculate:
             baseline_creat = self.addBaselineCreat(df)
             bc = self.addBackCalcAKI(df, baseline_creat = baseline_creat)
         
         if self.aki_calc_type == 'both':
+
+            # If add_baseline_creat or add_min_creat is True, rw and bc are tuples, respectively. So, we want to unpack it as we return it
             if self.add_baseline_creat and self.add_min_creat: 
                 return pd.concat([df, rw[0], rw[1], rw[2], bc[0], bc[1]], axis=1).reset_index()
             elif self.add_baseline_creat: 
